local mod = ...



-- Custom Component: Weather (rolling 14 day record) -------------------------------------------------------------------------------------
--[[

    {temp, precip}

    0 = cool     0 = dry
    1 = norm     
    2 = warm     2 = wet

]]--

local COMP_TAS_WEATHER = {
	TypeName = "COMP_TAS_WEATHER",
	ParentType = "COMPONENT",
	Properties = {
		{
            Name = "CurrentSystemDaysRemaining",
            Type = "integer",
            Default = 7,
            Flags = { "SAVE_GAME" }
        },
		{
            Name = "DailyWeatherRecord",
            Type = "list<vec2i>",
            Default = { 
                {1, 2}, -- normal weather for this season
                {1, 2},
                {1, 0},
                {1, 0},
                {1, 0},
                {1, 0},
                {1, 2},
                {1, 2},
                {1, 0},
                {1, 0},
                {1, 0},
                {1, 0},
                {1, 2},
                {1, 2},
                {1, 0},
                {1, 0},
                {1, 0},
                {1, 0},
                {1, 2},
                {1, 2},
                {1, 0},
            },
            Flags = { "SAVE_GAME" }
        },
    }
}



-- Register custom Class
mod:registerClass(COMP_TAS_WEATHER)



-- Attach class to the prefab manager which means it will be present in the game from the beginning
mod:registerPrefabComponent("PREFAB_MANAGER", { DataType = "COMP_TAS_WEATHER" } )



-- Resource: Temperature (for display purposes) -------------------------------------------------------------------------------------
mod:registerAssetId("icons/Temperature.png", "ICON_TEMPERATURE", "ATLAS_CELL")

mod:register({
	DataType = "RESOURCE",
	Id = "RESOURCE_TEMPERATURE",
	ResourceName = "RESOURCE_TEMPERATURE_NAME",
	Icon = "ICON_TEMPERATURE",
	ResourceTypeList = { "RESOURCE" },
    OrderId = 0,
	IsTradable = false,
    DisplayInInventory = true,
    DisplayInToolbar = true
})



-- Job: Crop Increase -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_CROP_INCREASE",
	JobName = "JOB_TAS_WEATHER_CROP_INCREASE_NAME",
	JobDescription = "JOB_TAS_WEATHER_CROP_INCREASE_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_INCREASE"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_INCREASE"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_INCREASE"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_INCREASE"
    }
})



-- Job: Crop Decrease -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_CROP_DECREASE",
	JobName = "JOB_TAS_WEATHER_CROP_DECREASE_NAME",
	JobDescription = "JOB_TAS_WEATHER_CROP_DECREASE_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_DECREASE"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_DECREASE"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_DECREASE"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_CROP_DECREASE"
    }
})



-- Job: Livestock Increase -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_LIVESTOCK_INCREASE",
	JobName = "JOB_TAS_WEATHER_LIVESTOCK_INCREASE_NAME",
	JobDescription = "JOB_TAS_WEATHER_LIVESTOCK_INCREASE_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_INCREASE"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_INCREASE"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_INCREASE"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_INCREASE"
    }
})



-- Job: Livestock Decrease -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_LIVESTOCK_DECREASE",
	JobName = "JOB_TAS_WEATHER_LIVESTOCK_DECREASE_NAME",
	JobDescription = "JOB_TAS_WEATHER_LIVESTOCK_DECREASE_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_DECREASE"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_DECREASE"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_DECREASE"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_LIVESTOCK_DECREASE"
    }
})



-- Job: Sun -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_SUN",
	JobName = "JOB_TAS_WEATHER_SUN_NAME",
	JobDescription = "JOB_TAS_WEATHER_SUN_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_SUN"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_SUN"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_SUN"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_SUN"
    }
})



-- Job: Rain -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_RAIN",
	JobName = "JOB_TAS_WEATHER_RAIN_NAME",
	JobDescription = "JOB_TAS_WEATHER_RAIN_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_RAIN"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_RAIN"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_RAIN"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_RAIN"
    }
})



-- Job: Temperature = 1 degree (winter cold) -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_TEMP1",
	JobName = "JOB_TAS_WEATHER_TEMP1_NAME",
	JobDescription = "JOB_TAS_WEATHER_TEMP1_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP1"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP1"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP1"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP1"
    }
})



-- Job: Temperature = 5 degrees (winter normal) -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_TEMP5",
	JobName = "JOB_TAS_WEATHER_TEMP5_NAME",
	JobDescription = "JOB_TAS_WEATHER_TEMP5_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP5"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP5"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP5"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP5"
    }
})



-- Job: Temperature = 10 degrees (winter warm, spring cold) -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_TEMP10",
	JobName = "JOB_TAS_WEATHER_TEMP10_NAME",
	JobDescription = "JOB_TAS_WEATHER_TEMP10_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP10"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP10"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP10"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP10"
    }
})



-- Job: Temperature = 15 degrees (spring normal, summer cold) -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_TEMP15",
	JobName = "JOB_TAS_WEATHER_TEMP15_NAME",
	JobDescription = "JOB_TAS_WEATHER_TEMP15_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP15"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP15"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP15"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP10"
    }
})



-- Job: Temperature = 20 degrees (spring warm, summer normal) -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_TEMP20",
	JobName = "JOB_TAS_WEATHER_TEMP20_NAME",
	JobDescription = "JOB_TAS_WEATHER_TEMP20_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP20"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP20"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP20"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP20"
    }
})



-- Job: Temperature = 25 degrees (summer warm) -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_TAS_WEATHER_TEMP25",
	JobName = "JOB_TAS_WEATHER_TEMP25_NAME",
	JobDescription = "JOB_TAS_WEATHER_TEMP25_DESC",
	IsLockedByDefault = true,
    Hidden = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 0.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP25"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP25"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP25"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_TAS_WEATHER_TEMP25"
    }
})



-- Quest: Weather: Crop Increase ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_CROP_INCREASE",
    Name = "QUEST_TAS_WEATHER_CROP_INCREASE_NAME",
    Description = "QUEST_TAS_WEATHER_CROP_INCREASE_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_CROP_INCREASE"
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "BERRIES",
                    "WHEAT",
                    "HERBS",
                    "HONEY",
                    "RESOURCE_VEGETABLE",
                    "RESOURCE_FRUIT",
                    "HOP",
                    "GRAPES",
                },
                YieldPercentage = 1.20,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 1
            },
            OptionalApplicator = "EVENT_TAS_WEATHER_SETUP_CROP_INCREASE"
        }
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_SETUP_CROP_INCREASE"
    }
})



-- Quest: Weather: Crop Decrease ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_CROP_DECREASE",
    Name = "QUEST_TAS_WEATHER_CROP_DECREASE_NAME",
    Description = "QUEST_TAS_WEATHER_CROP_DECREASE_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_CROP_DECREASE"
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "BERRIES",
                    "WHEAT",
                    "HERBS",
                    "HONEY",
                    "RESOURCE_VEGETABLE",
                    "RESOURCE_FRUIT",
                    "HOP",
                    "GRAPES",
                },
                YieldPercentage = 0.795,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 1
            },
            OptionalApplicator = "EVENT_TAS_WEATHER_SETUP_CROP_DECREASE"
        }
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_SETUP_CROP_DECREASE"
    }
})




-- Quest: Weather: Livestock Increase ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_LIVESTOCK_INCREASE",
    Name = "QUEST_TAS_WEATHER_LIVESTOCK_INCREASE_NAME",
    Description = "QUEST_TAS_WEATHER_LIVESTOCK_INCREASE_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_LIVESTOCK_INCREASE"
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "MILK",
                    "RESOURCE_POULTRY",
                    "BV1_EGG",
                    "RESOURCE_CATTLE",
                    "RESOURCE_PIG",
                    "RESOURCE_SHEEP",
                    "RESOURCE_GOAT",
                    "BOAR",
                },
                YieldPercentage = 1.20,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 1
            },
            OptionalApplicator = "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_INCREASE"
        }
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_INCREASE"
    }
})



-- Quest: Weather: Livestock Decrease ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_LIVESTOCK_DECREASE",
    Name = "QUEST_TAS_WEATHER_LIVESTOCK_DECREASE_NAME",
    Description = "QUEST_TAS_WEATHER_LIVESTOCK_DECREASE_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_LIVESTOCK_DECREASE"
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "MILK",
                    "RESOURCE_POULTRY",
                    "BV1_EGG",
                    "RESOURCE_CATTLE",
                    "RESOURCE_PIG",
                    "RESOURCE_SHEEP",
                    "RESOURCE_GOAT",
                    "BOAR",
                },
                YieldPercentage = 0.795,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 1
            },
            OptionalApplicator = "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_DECREASE"
        }
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_DECREASE"
    }
})



-- Quest: Weather: Rain ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_RAIN",
    Name = "QUEST_TAS_WEATHER_RAIN_NAME",
    Description = "QUEST_TAS_WEATHER_RAIN_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_RAIN"
    },
    QuestRewardList = {
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_RAIN"
    }
})



-- Quest: Weather: Sun ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_SUN",
    Name = "QUEST_TAS_WEATHER_SUN_NAME",
    Description = "QUEST_TAS_WEATHER_SUN_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_SUN"
    },
    QuestRewardList = {
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_SUN"
    }
})



-- Quest: Temperature = 1 ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_TEMP1",
    Name = "QUEST_TAS_WEATHER_TEMP1_NAME",
    Description = "QUEST_TAS_WEATHER_TEMP1_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_TEMP1"
    },
    QuestRewardList = nil,
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_TEMP1"
    }
})



-- Quest: Temperature = 5 ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_TEMP5",
    Name = "QUEST_TAS_WEATHER_TEMP5_NAME",
    Description = "QUEST_TAS_WEATHER_TEMP5_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_TEMP5"
    },
    QuestRewardList = nil,
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_TEMP5"
    }
})



-- Quest: Temperature = 10 ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_TEMP10",
    Name = "QUEST_TAS_WEATHER_TEMP10_NAME",
    Description = "QUEST_TAS_WEATHER_TEMP10_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_TEMP10"
    },
    QuestRewardList = nil,
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_TEMP10"
    }
})



-- Quest: Temperature = 15 ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_TEMP15",
    Name = "QUEST_TAS_WEATHER_TEMP15_NAME",
    Description = "QUEST_TAS_WEATHER_TEMP15_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_TEMP15"
    },
    QuestRewardList = nil,
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_TEMP15"
    }
})



-- Quest: Temperature = 20 ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_TEMP20",
    Name = "QUEST_TAS_WEATHER_TEMP20_NAME",
    Description = "QUEST_TAS_WEATHER_TEMP20_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_TEMP20"
    },
    QuestRewardList = nil,
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_TEMP20"
    }
})



-- Quest: Temperature = 25 ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_WEATHER_TEMP25",
    Name = "QUEST_TAS_WEATHER_TEMP25_NAME",
    Description = "QUEST_TAS_WEATHER_TEMP25_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
        Job = "JOB_TAS_WEATHER_TEMP25"
    },
    QuestRewardList = nil,
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = {
        DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
        Event = "EVENT_TAS_WEATHER_TEMP25"
    }
})



-- Default Balancing (event list) ---------------------------------------------------------------------------------------------
mod:override({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND", 
        "EVENT_TAS_WEATHER_SETUP_CROP_INCREASE",
        "EVENT_TAS_WEATHER_SETUP_CROP_DECREASE",
        "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_INCREASE",
        "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_DECREASE",
        "EVENT_TAS_WEATHER_SETUP_RAIN",
        "EVENT_TAS_WEATHER_SETUP_SUN",
        "EVENT_TAS_WEATHER_SETUP_TEMP",
    },
})



-- Event: Weather: Setup Crop Increase ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SETUP_CROP_INCREASE",
    Title = "EVENT_TAS_WEATHER_SETUP_TITLE",
	Description = "EVENT_TAS_WEATHER_SETUP_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_CROP_INCREASE"
        },
    }
})



-- Event: Weather: Setup Crop Decrease ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SETUP_CROP_DECREASE",
    Title = "EVENT_TAS_WEATHER_SETUP_TITLE",
	Description = "EVENT_TAS_WEATHER_SETUP_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_CROP_DECREASE"
        },
    }
})



-- Event: Weather: Setup Livestock Increase ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_INCREASE",
    Title = "EVENT_TAS_WEATHER_SETUP_TITLE",
	Description = "EVENT_TAS_WEATHER_SETUP_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_LIVESTOCK_INCREASE"
        },
    }
})



-- Event: Weather: Setup Livestock Decrease ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SETUP_LIVESTOCK_DECREASE",
    Title = "EVENT_TAS_WEATHER_SETUP_TITLE",
	Description = "EVENT_TAS_WEATHER_SETUP_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_LIVESTOCK_DECREASE"
        },
    }
})



-- Event: Weather: Setup Rain ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SETUP_RAIN",
    Title = "EVENT_TAS_WEATHER_SETUP_RAIN_TITLE",
	Description = "EVENT_TAS_WEATHER_SETUP_RAIN_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_RAIN"
        },
    }
})



-- Event: Weather: Setup Sun ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SETUP_SUN",
    Title = "EVENT_TAS_WEATHER_SETUP_SUN_TITLE",
	Description = "EVENT_TAS_WEATHER_SETUP_SUN_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_SUN"
        },
    }
})



-- Event: Setup Weather: Temperature ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SETUP_TEMP",
    Title = "EVENT_TAS_WEATHER_SETUP_TEMP_TITLE",
	Description = "EVENT_TAS_WEATHER_SETUP_TEMP_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "BUILDING_VILLAGE_CENTER"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP1"
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP5"
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP10"
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP15"
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP20"
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP25"
        },
    }
})



-- Event: Weather: Sun ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_SUN",
    Title = "EVENT_TAS_WEATHER_SUN_TITLE",
	Description = "EVENT_TAS_WEATHER_SUN_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_CHANGE_WEATHER",
            AssetWeather = "WEATHER_SUNNY",
            IsWeatherSystemOverriden = true,
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_SUN"
        },
    }
})



-- Event: Weather: Rain ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_RAIN",
    Title = "EVENT_TAS_WEATHER_RAIN_TITLE",
	Description = "EVENT_TAS_WEATHER_RAIN_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_CHANGE_WEATHER",
            AssetWeather = "WEATHER_RAINY",
            IsWeatherSystemOverriden = true,
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_RAIN"
        },
    }
})



-- Event: Weather: Temperature = 1 ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_TEMP1",
    Title = "EVENT_TAS_WEATHER_TEMP1_TITLE",
	Description = "EVENT_TAS_WEATHER_TEMP1_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_TEMPERATURE",
                    Quantity = 100
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_TEMPERATURE",
                            Quantity = 1
                        },
                    }
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP1"
        },
    }
})



-- Event: Weather: Temperature = 5 ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_TEMP5",
    Title = "EVENT_TAS_WEATHER_TEMP5_TITLE",
	Description = "EVENT_TAS_WEATHER_TEMP5_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_TEMPERATURE",
                    Quantity = 100
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_TEMPERATURE",
                            Quantity = 5
                        },
                    }
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP5"
        },
    }
})



-- Event: Weather: Temperature = 10 ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_TEMP10",
    Title = "EVENT_TAS_WEATHER_TEMP10_TITLE",
	Description = "EVENT_TAS_WEATHER_TEMP10_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_TEMPERATURE",
                    Quantity = 100
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_TEMPERATURE",
                            Quantity = 10
                        },
                    }
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP10"
        },
    }
})



-- Event: Weather: Temperature = 15 ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_TEMP15",
    Title = "EVENT_TAS_WEATHER_TEMP15_TITLE",
	Description = "EVENT_TAS_WEATHER_TEMP15_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_TEMPERATURE",
                    Quantity = 100
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_TEMPERATURE",
                            Quantity = 15
                        },
                    }
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP15"
        },
    }
})



-- Event: Weather: Temperature = 20 ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_TEMP20",
    Title = "EVENT_TAS_WEATHER_TEMP20_TITLE",
	Description = "EVENT_TAS_WEATHER_TEMP20_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_TEMPERATURE",
                    Quantity = 100
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_TEMPERATURE",
                            Quantity = 20
                        },
                    }
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP20"
        },
    }
})



-- Event: Weather: Temperature = 25 ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_WEATHER_TEMP25",
    Title = "EVENT_TAS_WEATHER_TEMP25_TITLE",
	Description = "EVENT_TAS_WEATHER_TEMP25_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "RESOURCE_TEMPERATURE",
                    Quantity = 100
                }
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_RESOURCES",
                    ResourceCollection = {
                        {
                            Resource = "RESOURCE_TEMPERATURE",
                            Quantity = 25
                        },
                    }
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_WEATHER_TEMP25"
        },
    }
})
